You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@camel.apache.org by wt...@apache.org on 2009/03/23 04:18:51 UTC

svn commit: r757308 - /camel/trunk/components/camel-cxf/src/main/java/org/apache/camel/component/cxf/CxfConstants.java

Author: wtam
Date: Mon Mar 23 03:18:51 2009
New Revision: 757308

URL: http://svn.apache.org/viewvc?rev=757308&view=rev
Log:
change property name to CamelCXFDataFormat

Modified:
    camel/trunk/components/camel-cxf/src/main/java/org/apache/camel/component/cxf/CxfConstants.java

Modified: camel/trunk/components/camel-cxf/src/main/java/org/apache/camel/component/cxf/CxfConstants.java
URL: http://svn.apache.org/viewvc/camel/trunk/components/camel-cxf/src/main/java/org/apache/camel/component/cxf/CxfConstants.java?rev=757308&r1=757307&r2=757308&view=diff
==============================================================================
--- camel/trunk/components/camel-cxf/src/main/java/org/apache/camel/component/cxf/CxfConstants.java (original)
+++ camel/trunk/components/camel-cxf/src/main/java/org/apache/camel/component/cxf/CxfConstants.java Mon Mar 23 03:18:51 2009
@@ -24,8 +24,8 @@
 public interface CxfConstants {
     String METHOD = "method";
     String SERVICE_CLASS = "serviceClass";
-    // org.apache.camel.cxf.dataFormat is used as exchange property key
-    String DATA_FORMAT_PROPERTY = "org.apache.camel.cxf.dataFormat";
+    // CamelCXFDataFormat is used as exchange property key
+    String DATA_FORMAT_PROPERTY = "CamelCXFDataFormat";
     String SET_DEFAULT_BUS = "setDefaultBus";
     String WSDL_URL = "wsdlURL";
     String ADDRESS = "address";